/* eslint-disable @next/next/no-img-element */
import { CachedPlayer, SkinPart } from "mcutils-library";
import { ReactElement } from "react";
import { Card } from "../card";
import { CodeDialog } from "../code-dialog";
import { Separator } from "../ui/separator";
import { SkinPartImage } from "./skin-part-image";

type PlayerViewProps = {
  /**
   * The player to display.
   */
  player: CachedPlayer;
};

export function PlayerView({ player }: PlayerViewProps): ReactElement {
  return (
    <Card className="w-max xs:w-fit">
      <div className="flex gap-4 flex-col xs:flex-row relative">
        <div className="absolute 8xl:top-0 xs:bottom-0">
          <CodeDialog
            title="Player Data"
            description="The player's data from the API"
            code={JSON.stringify(player, undefined, 2)}
          >
            <button className="bg-background rounded-lg">
              <p className="p-1">JSON</p>
            </button>
          </CodeDialog>
        </div>

        <div className="flex items-center flex-col">
          <SkinPartImage playerName={player.username} part={SkinPart.HEAD} url={player.skin.parts.head} size={96} />
        </div>

        <div className="flex flex-col gap-2">
          <div>
            <h2 className="text-xl text-primary font-semibold">{player.username}</h2>
            <p>{player.uniqueId}</p>
          </div>

          <Separator />

          <div className="flex flex-col gap-2">
            <p className="text-lg">Skin Parts</p>
            <div className="flex gap-2">
              {Object.entries(player.skin.parts)
                .filter(([part]) => part !== SkinPart.HEAD) // Don't show the head part again
                .map(([part, url]) => {
                  return <SkinPartImage key={part} playerName={player.username} part={part as SkinPart} url={url} />;
                })}
            </div>
          </div>
        </div>
      </div>
    </Card>
  );
}
